@@ -118,6 +118,36 @@ static const uint32_t pp_yuv420p8_scaling_gen9[][4] = {
 #include "shaders/post_processing/gen9/conv_nv12.g9b"
 };
 
+static const uint32_t pp_10bit_8bit_scaling_gen9[][4] = {
+#include "shaders/post_processing/gen9/conv_10bit_8bit.g9b"
+};
+
+struct i965_kernel pp_common_scaling_gen9[] = {
+    {
+        "10bit to 10bit",
+        0,
+        pp_10bit_scaling_gen9,
+        sizeof(pp_10bit_scaling_gen9),
+        NULL,
+    },
+
+    {
+        "8bit to 8bit",
+        1,
+        pp_yuv420p8_scaling_gen9,
+        sizeof(pp_yuv420p8_scaling_gen9),
+        NULL,
+    },
+
+    {
+        "10bit to 8bit",
+        2,
+        pp_10bit_8bit_scaling_gen9,
+        sizeof(pp_10bit_8bit_scaling_gen9),
+        NULL,
+    },
+};
+
 static struct pp_module pp_modules_gen9[] = {
     {
         {
@@ -367,7 +397,7 @@ gen9_pp_state_base_address(VADriverContextP ctx,
     OUT_RELOC64(batch, pp_context->surface_state_binding_table.bo, I915_GEM_DOMAIN_INSTRUCTION, 0, BASE_ADDRESS_MODIFY); /* Surface state base address */
     /* DW6-7 Dynamic state address */
     OUT_RELOC64(batch, pp_context->dynamic_state.bo, I915_GEM_DOMAIN_RENDER | I915_GEM_DOMAIN_SAMPLER,
-              0, 0 | BASE_ADDRESS_MODIFY);
+                0, 0 | BASE_ADDRESS_MODIFY);
 
     /* DW8. Indirect object address */
     OUT_BATCH(batch, 0 | BASE_ADDRESS_MODIFY);
@@ -455,9 +485,9 @@ gen9_post_processing(VADriverContextP ctx,
 
 static void
 gen9_vpp_scaling_sample_state(VADriverContextP ctx,
-                               struct i965_gpe_context *gpe_context,
-                               VARectangle *src_rect,
-                               VARectangle *dst_rect)
+                              struct i965_gpe_context *gpe_context,
+                              VARectangle *src_rect,
+                              VARectangle *dst_rect)
 {
     struct gen8_sampler_state *sampler_state;
 
@@ -471,7 +501,7 @@ gen9_vpp_scaling_sample_state(VADriverContextP ctx,
     assert(gpe_context->sampler.bo->virtual);
 
     sampler_state = (struct gen8_sampler_state *)
-       (gpe_context->sampler.bo->virtual + gpe_context->sampler.offset);
+                    (gpe_context->sampler.bo->virtual + gpe_context->sampler.offset);
 
     memset(sampler_state, 0, sizeof(*sampler_state));
 
@@ -499,20 +529,16 @@ gen9_post_processing_context_init(VADriverContextP ctx,
     struct i965_driver_data *i965 = i965_driver_data(ctx);
     struct i965_post_processing_context *pp_context = data;
     struct i965_gpe_context *gpe_context;
-    struct i965_kernel scaling_kernel;
 
     gen8_post_processing_context_common_init(ctx, data, pp_modules_gen9, ARRAY_ELEMS(pp_modules_gen9), batch);
     avs_init_state(&pp_context->pp_avs_context.state, &gen9_avs_config);
 
     pp_context->intel_post_processing = gen9_post_processing;
 
-    gpe_context = &pp_context->scaling_10bit_context;
-    memset(&scaling_kernel, 0, sizeof(scaling_kernel));
-    scaling_kernel.bin = pp_10bit_scaling_gen9;
-    scaling_kernel.size = sizeof(pp_10bit_scaling_gen9);
-    gen8_gpe_load_kernels(ctx, gpe_context, &scaling_kernel, 1);
+    gpe_context = &pp_context->scaling_gpe_context;
+    gen8_gpe_load_kernels(ctx, gpe_context, pp_common_scaling_gen9, ARRAY_ELEMS(pp_common_scaling_gen9));
     gpe_context->idrt.entry_size = ALIGN(sizeof(struct gen8_interface_descriptor_data), 64);
-    gpe_context->idrt.max_entries = 1;
+    gpe_context->idrt.max_entries = ALIGN(ARRAY_ELEMS(pp_common_scaling_gen9), 2);
     gpe_context->sampler.entry_size = ALIGN(sizeof(struct gen8_sampler_state), 64);
     gpe_context->sampler.max_entries = 1;
     gpe_context->curbe.length = ALIGN(sizeof(struct scaling_input_parameter), 64);
@@ -537,46 +563,8 @@ gen9_post_processing_context_init(VADriverContextP ctx,
     gpe_context->vfe_state.gpgpu_mode = 0;
 
     gen8_gpe_context_init(ctx, gpe_context);
-    pp_context->scaling_context_initialized = 1;
+    pp_context->scaling_gpe_context_initialized |= (VPPGPE_8BIT_8BIT | VPPGPE_10BIT_10BIT | VPPGPE_10BIT_8BIT);
 
-    /* initialize the YUV420 8-Bit scaling context. The below is supported.
-     * NV12 ->NV12
-     * NV12 ->I420
-     * I420 ->I420
-     * I420 ->NV12
-     */
-    gpe_context = &pp_context->scaling_yuv420p8_context;
-    memset(&scaling_kernel, 0, sizeof(scaling_kernel));
-    scaling_kernel.bin = pp_yuv420p8_scaling_gen9;
-    scaling_kernel.size = sizeof(pp_yuv420p8_scaling_gen9);
-    gen8_gpe_load_kernels(ctx, gpe_context, &scaling_kernel, 1);
-    gpe_context->idrt.entry_size = ALIGN(sizeof(struct gen8_interface_descriptor_data), 64);
-    gpe_context->idrt.max_entries = 1;
-    gpe_context->sampler.entry_size = ALIGN(sizeof(struct gen8_sampler_state), 64);
-    gpe_context->sampler.max_entries = 1;
-    gpe_context->curbe.length = ALIGN(sizeof(struct scaling_input_parameter), 32);
-
-    gpe_context->surface_state_binding_table.max_entries = MAX_SCALING_SURFACES;
-    gpe_context->surface_state_binding_table.binding_table_offset = 0;
-    gpe_context->surface_state_binding_table.surface_state_offset = ALIGN(MAX_SCALING_SURFACES * 4, 64);
-    gpe_context->surface_state_binding_table.length = ALIGN(MAX_SCALING_SURFACES * 4, 64) + ALIGN(MAX_SCALING_SURFACES * SURFACE_STATE_PADDED_SIZE_GEN9, 64);
-
-    if (i965->intel.eu_total > 0) {
-        gpe_context->vfe_state.max_num_threads = i965->intel.eu_total * 6;
-    } else {
-        if (i965->intel.has_bsd2)
-            gpe_context->vfe_state.max_num_threads = 300;
-        else
-            gpe_context->vfe_state.max_num_threads = 60;
-    }
-
-    gpe_context->vfe_state.curbe_allocation_size = 37;
-    gpe_context->vfe_state.urb_entry_size = 16;
-    gpe_context->vfe_state.num_urb_entries = 127;
-    gpe_context->vfe_state.gpgpu_mode = 0;
-
-    gen8_gpe_context_init(ctx, gpe_context);
-    pp_context->scaling_8bit_initialized = VPPGPE_8BIT_420;
     return;
 }
 
@@ -591,7 +579,7 @@ gen9_add_dri_buffer_2d_gpe_surface(VADriverContextP ctx,
                                    int is_media_block_rw,
                                    unsigned int format,
                                    int index,
-                                   int is_10bit)
+                                   int is_16bit)
 {
     struct i965_gpe_resource gpe_resource;
     struct i965_gpe_surface gpe_surface;
@@ -605,7 +593,7 @@ gen9_add_dri_buffer_2d_gpe_surface(VADriverContextP ctx,
     gpe_surface.format = format;
     gpe_surface.is_override_offset = 1;
     gpe_surface.offset = bo_offset;
-    gpe_surface.is_16bpp = is_10bit;
+    gpe_surface.is_16bpp = is_16bit;
 
     gen9_gpe_context_add_surface(gpe_context, &gpe_surface, index);
 
@@ -637,29 +625,13 @@ gen9_run_kernel_media_object_walker(VADriverContextP ctx,
     return;
 }
 
-static unsigned int
-pp_get_surface_fourcc(VADriverContextP ctx, struct i965_surface *surface)
-{
-    unsigned int fourcc;
-
-    if (surface->type == I965_SURFACE_TYPE_IMAGE) {
-        struct object_image *obj_image = (struct object_image *)surface->base;
-        fourcc = obj_image->image.format.fourcc;
-    } else {
-        struct object_surface *obj_surface = (struct object_surface *)surface->base;
-        fourcc = obj_surface->fourcc;
-    }
-
-    return fourcc;
-}
-
 static void
 gen9_gpe_context_p010_scaling_curbe(VADriverContextP ctx,
-                               struct i965_gpe_context *gpe_context,
-                               VARectangle *src_rect,
-                               struct i965_surface *src_surface,
-                               VARectangle *dst_rect,
-                               struct i965_surface *dst_surface)
+                                    struct i965_gpe_context *gpe_context,
+                                    VARectangle *src_rect,
+                                    struct i965_surface *src_surface,
+                                    VARectangle *dst_rect,
+                                    struct i965_surface *dst_surface)
 {
     struct scaling_input_parameter *scaling_curbe;
     float src_width, src_height;
@@ -691,11 +663,11 @@ gen9_gpe_context_p010_scaling_curbe(VADriverContextP ctx,
     scaling_curbe->inv_width = 1 / src_width;
     scaling_curbe->inv_height = 1 / src_height;
 
-    coeff = (float) (src_rect->width) / dst_rect->width;
+    coeff = (float)(src_rect->width) / dst_rect->width;
     scaling_curbe->x_factor = coeff / src_width;
     scaling_curbe->x_orig = (float)(src_rect->x) / src_width;
 
-    coeff = (float) (src_rect->height) / dst_rect->height;
+    coeff = (float)(src_rect->height) / dst_rect->height;
     scaling_curbe->y_factor = coeff / src_height;
     scaling_curbe->y_orig = (float)(src_rect->y) / src_height;
 
@@ -748,6 +720,8 @@ gen9_pp_context_get_surface_conf(VADriverContextP ctx,
             height[1] = height[0] / 2;
             pitch[1] = obj_surface->cb_cr_pitch;
             bo_offset[1] = obj_surface->width * obj_surface->y_cb_offset;
+        } else if (fourcc == VA_FOURCC_YUY2 || fourcc == VA_FOURCC_UYVY) {
+            /* nothing to do here */
         } else {
             /* I010/I420 format */
             width[1] = width[0] / 2;
@@ -775,6 +749,8 @@ gen9_pp_context_get_surface_conf(VADriverContextP ctx,
             height[1] = height[0] / 2;
             pitch[1] = obj_image->image.pitches[1];
             bo_offset[1] = obj_image->image.offsets[1];
+        } else if (fourcc == VA_FOURCC_YUY2 || fourcc == VA_FOURCC_UYVY) {
+            /* nothing to do here */
         } else {
             /* I010/I420 format */
             width[1] = width[0] / 2;
@@ -794,11 +770,11 @@ gen9_pp_context_get_surface_conf(VADriverContextP ctx,
 
 static void
 gen9_gpe_context_p010_scaling_surfaces(VADriverContextP ctx,
-                               struct i965_gpe_context *gpe_context,
-                               VARectangle *src_rect,
-                               struct i965_surface *src_surface,
-                               VARectangle *dst_rect,
-                               struct i965_surface *dst_surface)
+                                       struct i965_gpe_context *gpe_context,
+                                       VARectangle *src_rect,
+                                       struct i965_surface *src_surface,
+                                       VARectangle *dst_rect,
+                                       struct i965_surface *dst_surface)
 {
     unsigned int fourcc;
     int width[3], height[3], pitch[3], bo_offset[3];
@@ -839,25 +815,25 @@ gen9_gpe_context_p010_scaling_surfaces(VADriverContextP ctx,
                                            bti, 1);
         if (fourcc == VA_FOURCC_P010) {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 0,
-                                           I965_SURFACEFORMAT_R16G16_UNORM,
-                                           bti + 1, 1);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R16G16_UNORM,
+                                               bti + 1, 1);
         } else {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 0,
-                                           I965_SURFACEFORMAT_R16_UNORM,
-                                           bti + 1, 1);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R16_UNORM,
+                                               bti + 1, 1);
 
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[2],
-                                           width[2], height[2],
-                                           pitch[2], 0,
-                                           I965_SURFACEFORMAT_R16_UNORM,
-                                           bti + 2, 1);
+                                               bo_offset[2],
+                                               width[2], height[2],
+                                               pitch[2], 0,
+                                               I965_SURFACEFORMAT_R16_UNORM,
+                                               bti + 2, 1);
         }
     }
 
@@ -884,25 +860,25 @@ gen9_gpe_context_p010_scaling_surfaces(VADriverContextP ctx,
                                            bti, 1);
         if (fourcc == VA_FOURCC_P010) {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1] * 2, height[1],
-                                           pitch[1], 1,
-                                           I965_SURFACEFORMAT_R16_UINT,
-                                           bti + 1, 1);
+                                               bo_offset[1],
+                                               width[1] * 2, height[1],
+                                               pitch[1], 1,
+                                               I965_SURFACEFORMAT_R16_UINT,
+                                               bti + 1, 1);
         } else {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 1,
-                                           I965_SURFACEFORMAT_R16_UINT,
-                                           bti + 1, 1);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 1,
+                                               I965_SURFACEFORMAT_R16_UINT,
+                                               bti + 1, 1);
 
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[2],
-                                           width[2], height[2],
-                                           pitch[2], 1,
-                                           I965_SURFACEFORMAT_R16_UINT,
-                                           bti + 2, 1);
+                                               bo_offset[2],
+                                               width[2], height[2],
+                                               pitch[2], 1,
+                                               I965_SURFACEFORMAT_R16_UINT,
+                                               bti + 2, 1);
         }
     }
 
@@ -925,10 +901,10 @@ gen9_p010_scaling_post_processing(
     if (!pp_context || !src_surface || !src_rect || !dst_surface || !dst_rect)
         return VA_STATUS_ERROR_INVALID_PARAMETER;
 
-    if (!pp_context->scaling_context_initialized)
+    if (!(pp_context->scaling_gpe_context_initialized & VPPGPE_10BIT_10BIT))
         return VA_STATUS_ERROR_UNIMPLEMENTED;
 
-    gpe_context = &pp_context->scaling_10bit_context;
+    gpe_context = &pp_context->scaling_gpe_context;
 
     gen8_gpe_context_init(ctx, gpe_context);
     gen9_vpp_scaling_sample_state(ctx, gpe_context, src_rect, dst_rect);
@@ -938,8 +914,8 @@ gen9_p010_scaling_post_processing(
                                         dst_rect, dst_surface);
 
     gen9_gpe_context_p010_scaling_surfaces(ctx, gpe_context,
-                                        src_rect, src_surface,
-                                        dst_rect, dst_surface);
+                                           src_rect, src_surface,
+                                           dst_rect, dst_surface);
 
     gen8_gpe_setup_interface_data(ctx, gpe_context);
 
@@ -949,7 +925,7 @@ gen9_p010_scaling_post_processing(
     kernel_walker_param.no_dependency = 1;
 
     intel_vpp_init_media_object_walker_parameter(&kernel_walker_param, &media_object_walker_param);
-
+    media_object_walker_param.interface_offset = 0;
     gen9_run_kernel_media_object_walker(ctx, pp_context->batch,
                                         gpe_context,
                                         &media_object_walker_param);
@@ -959,11 +935,11 @@ gen9_p010_scaling_post_processing(
 
 static void
 gen9_gpe_context_yuv420p8_scaling_curbe(VADriverContextP ctx,
-                               struct i965_gpe_context *gpe_context,
-                               VARectangle *src_rect,
-                               struct i965_surface *src_surface,
-                               VARectangle *dst_rect,
-                               struct i965_surface *dst_surface)
+                                        struct i965_gpe_context *gpe_context,
+                                        VARectangle *src_rect,
+                                        struct i965_surface *src_surface,
+                                        VARectangle *dst_rect,
+                                        struct i965_surface *dst_surface)
 {
     struct scaling_input_parameter *scaling_curbe;
     float src_width, src_height;
@@ -995,11 +971,11 @@ gen9_gpe_context_yuv420p8_scaling_curbe(VADriverContextP ctx,
     scaling_curbe->inv_width = 1 / src_width;
     scaling_curbe->inv_height = 1 / src_height;
 
-    coeff = (float) (src_rect->width) / dst_rect->width;
+    coeff = (float)(src_rect->width) / dst_rect->width;
     scaling_curbe->x_factor = coeff / src_width;
     scaling_curbe->x_orig = (float)(src_rect->x) / src_width;
 
-    coeff = (float) (src_rect->height) / dst_rect->height;
+    coeff = (float)(src_rect->height) / dst_rect->height;
     scaling_curbe->y_factor = coeff / src_height;
     scaling_curbe->y_orig = (float)(src_rect->y) / src_height;
 
@@ -1019,11 +995,11 @@ gen9_gpe_context_yuv420p8_scaling_curbe(VADriverContextP ctx,
 
 static void
 gen9_gpe_context_yuv420p8_scaling_surfaces(VADriverContextP ctx,
-                               struct i965_gpe_context *gpe_context,
-                               VARectangle *src_rect,
-                               struct i965_surface *src_surface,
-                               VARectangle *dst_rect,
-                               struct i965_surface *dst_surface)
+                                           struct i965_gpe_context *gpe_context,
+                                           VARectangle *src_rect,
+                                           struct i965_surface *src_surface,
+                                           VARectangle *dst_rect,
+                                           struct i965_surface *dst_surface)
 {
     unsigned int fourcc;
     int width[3], height[3], pitch[3], bo_offset[3];
@@ -1064,25 +1040,25 @@ gen9_gpe_context_yuv420p8_scaling_surfaces(VADriverContextP ctx,
                                            bti, 0);
         if (fourcc == VA_FOURCC_NV12) {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 0,
-                                           I965_SURFACEFORMAT_R8G8_UNORM,
-                                           bti + 1, 0);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R8G8_UNORM,
+                                               bti + 1, 0);
         } else {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 0,
-                                           I965_SURFACEFORMAT_R8_UNORM,
-                                           bti + 1, 0);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R8_UNORM,
+                                               bti + 1, 0);
 
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[2],
-                                           width[2], height[2],
-                                           pitch[2], 0,
-                                           I965_SURFACEFORMAT_R8_UNORM,
-                                           bti + 2, 0);
+                                               bo_offset[2],
+                                               width[2], height[2],
+                                               pitch[2], 0,
+                                               I965_SURFACEFORMAT_R8_UNORM,
+                                               bti + 2, 0);
         }
     }
 
@@ -1109,25 +1085,25 @@ gen9_gpe_context_yuv420p8_scaling_surfaces(VADriverContextP ctx,
                                            bti, 0);
         if (fourcc == VA_FOURCC_NV12) {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1] * 2, height[1],
-                                           pitch[1], 1,
-                                           I965_SURFACEFORMAT_R16_UINT,
-                                           bti + 1, 0);
+                                               bo_offset[1],
+                                               width[1] * 2, height[1],
+                                               pitch[1], 1,
+                                               I965_SURFACEFORMAT_R16_UINT,
+                                               bti + 1, 0);
         } else {
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[1],
-                                           width[1], height[1],
-                                           pitch[1], 1,
-                                           I965_SURFACEFORMAT_R8_UINT,
-                                           bti + 1, 0);
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 1,
+                                               I965_SURFACEFORMAT_R8_UINT,
+                                               bti + 1, 0);
 
             gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
-                                           bo_offset[2],
-                                           width[2], height[2],
-                                           pitch[2], 1,
-                                           I965_SURFACEFORMAT_R8_UINT,
-                                           bti + 2, 0);
+                                               bo_offset[2],
+                                               width[2], height[2],
+                                               pitch[2], 1,
+                                               I965_SURFACEFORMAT_R8_UINT,
+                                               bti + 2, 0);
         }
     }
 
@@ -1150,21 +1126,21 @@ gen9_yuv420p8_scaling_post_processing(
     if (!pp_context || !src_surface || !src_rect || !dst_surface || !dst_rect)
         return VA_STATUS_ERROR_INVALID_PARAMETER;
 
-    if (!(pp_context->scaling_8bit_initialized & VPPGPE_8BIT_420))
+    if (!(pp_context->scaling_gpe_context_initialized & VPPGPE_8BIT_8BIT))
         return VA_STATUS_ERROR_UNIMPLEMENTED;
 
-    gpe_context = &pp_context->scaling_yuv420p8_context;
+    gpe_context = &pp_context->scaling_gpe_context;
 
     gen8_gpe_context_init(ctx, gpe_context);
     gen9_vpp_scaling_sample_state(ctx, gpe_context, src_rect, dst_rect);
     gen9_gpe_reset_binding_table(ctx, gpe_context);
     gen9_gpe_context_yuv420p8_scaling_curbe(ctx, gpe_context,
-                                        src_rect, src_surface,
-                                        dst_rect, dst_surface);
+                                            src_rect, src_surface,
+                                            dst_rect, dst_surface);
 
     gen9_gpe_context_yuv420p8_scaling_surfaces(ctx, gpe_context,
-                                        src_rect, src_surface,
-                                        dst_rect, dst_surface);
+                                               src_rect, src_surface,
+                                               dst_rect, dst_surface);
 
     gen8_gpe_setup_interface_data(ctx, gpe_context);
 
@@ -1174,7 +1150,271 @@ gen9_yuv420p8_scaling_post_processing(
     kernel_walker_param.no_dependency = 1;
 
     intel_vpp_init_media_object_walker_parameter(&kernel_walker_param, &media_object_walker_param);
+    media_object_walker_param.interface_offset = 1;
+    gen9_run_kernel_media_object_walker(ctx, pp_context->batch,
+                                        gpe_context,
+                                        &media_object_walker_param);
 
+    return VA_STATUS_SUCCESS;
+}
+
+static void
+gen9_gpe_context_10bit_8bit_scaling_curbe(VADriverContextP ctx,
+                                          struct i965_gpe_context *gpe_context,
+                                          VARectangle *src_rect,
+                                          struct i965_surface *src_surface,
+                                          VARectangle *dst_rect,
+                                          struct i965_surface *dst_surface)
+{
+    struct scaling_input_parameter *scaling_curbe;
+    float src_width, src_height;
+    float coeff;
+    unsigned int fourcc;
+    int src_format = SRC_FORMAT_P010, dst_format = DST_FORMAT_YUY2;
+
+    if ((gpe_context == NULL) ||
+        (src_rect == NULL) || (src_surface == NULL) ||
+        (dst_rect == NULL) || (dst_surface == NULL))
+        return;
+
+    scaling_curbe = i965_gpe_context_map_curbe(gpe_context);
+
+    if (!scaling_curbe)
+        return;
+
+    memset(scaling_curbe, 0, sizeof(struct scaling_input_parameter));
+
+    scaling_curbe->bti_input = BTI_SCALING_INPUT_Y;
+    scaling_curbe->bti_output = BTI_SCALING_OUTPUT_Y;
+
+    /* As the src_rect/dst_rect is already checked, it is skipped.*/
+    scaling_curbe->x_dst     = dst_rect->x;
+    scaling_curbe->y_dst     = dst_rect->y;
+
+    src_width = src_rect->x + src_rect->width;
+    src_height = src_rect->y + src_rect->height;
+
+    scaling_curbe->inv_width = 1 / src_width;
+    scaling_curbe->inv_height = 1 / src_height;
+
+    coeff = (float)(src_rect->width) / dst_rect->width;
+    scaling_curbe->x_factor = coeff / src_width;
+    scaling_curbe->x_orig = (float)(src_rect->x) / src_width;
+
+    coeff = (float)(src_rect->height) / dst_rect->height;
+    scaling_curbe->y_factor = coeff / src_height;
+    scaling_curbe->y_orig = (float)(src_rect->y) / src_height;
+
+    fourcc = pp_get_surface_fourcc(ctx, src_surface);
+
+    switch (fourcc) {
+    case VA_FOURCC_P010:
+        src_format = SRC_FORMAT_P010;
+        break;
+
+    case VA_FOURCC_I010:
+        src_format = SRC_FORMAT_I010;
+        break;
+
+    default:
+        break;
+    }
+
+    fourcc = pp_get_surface_fourcc(ctx, dst_surface);
+
+    switch (fourcc) {
+    case VA_FOURCC_YUY2:
+        dst_format = DST_FORMAT_YUY2;
+        break;
+
+    case VA_FOURCC_UYVY:
+        dst_format = DST_FORMAT_UYVY;
+        break;
+
+    case VA_FOURCC_NV12:
+        dst_format = DST_FORMAT_NV12;
+        break;
+
+    case VA_FOURCC_I420:
+        dst_format = DST_FORMAT_I420;
+        break;
+
+    default:
+        break;
+    }
+
+    scaling_curbe->dw7.src_format = src_format;
+    scaling_curbe->dw7.dst_format = dst_format;
+
+    i965_gpe_context_unmap_curbe(gpe_context);
+}
+
+static void
+gen9_gpe_context_10bit_8bit_scaling_surfaces(VADriverContextP ctx,
+                                             struct i965_gpe_context *gpe_context,
+                                             VARectangle *src_rect,
+                                             struct i965_surface *src_surface,
+                                             VARectangle *dst_rect,
+                                             struct i965_surface *dst_surface)
+{
+    unsigned int fourcc;
+    int width[3], height[3], pitch[3], bo_offset[3];
+    dri_bo *bo;
+    struct object_surface *obj_surface;
+    struct object_image *obj_image;
+    int bti;
+
+    if ((gpe_context == NULL) ||
+        (src_rect == NULL) || (src_surface == NULL) ||
+        (dst_rect == NULL) || (dst_surface == NULL))
+        return;
+
+    if (src_surface->base == NULL || dst_surface->base == NULL)
+        return;
+
+    fourcc = pp_get_surface_fourcc(ctx, src_surface);
+
+    if (src_surface->type == I965_SURFACE_TYPE_SURFACE) {
+        obj_surface = (struct object_surface *)src_surface->base;
+        bo = obj_surface->bo;
+    } else {
+        obj_image = (struct object_image *)src_surface->base;
+        bo = obj_image->bo;
+    }
+
+    bti = 0;
+    if (gen9_pp_context_get_surface_conf(ctx, src_surface, src_rect,
+                                         width, height, pitch,
+                                         bo_offset)) {
+        bti = BTI_SCALING_INPUT_Y;
+        /* Input surface */
+        gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                           bo_offset[0],
+                                           width[0], height[0],
+                                           pitch[0], 0,
+                                           I965_SURFACEFORMAT_R16_UNORM,
+                                           bti, 1);
+        if (fourcc == VA_FOURCC_P010) {
+            gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R16G16_UNORM,
+                                               bti + 1, 1);
+        } else {
+            gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                               bo_offset[1],
+                                               width[1], height[1],
+                                               pitch[1], 0,
+                                               I965_SURFACEFORMAT_R16_UNORM,
+                                               bti + 1, 1);
+
+            gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                               bo_offset[2],
+                                               width[2], height[2],
+                                               pitch[2], 0,
+                                               I965_SURFACEFORMAT_R16_UNORM,
+                                               bti + 2, 1);
+        }
+    }
+
+    fourcc = pp_get_surface_fourcc(ctx, dst_surface);
+
+    if (dst_surface->type == I965_SURFACE_TYPE_SURFACE) {
+        obj_surface = (struct object_surface *)dst_surface->base;
+        bo = obj_surface->bo;
+    } else {
+        obj_image = (struct object_image *)dst_surface->base;
+        bo = obj_image->bo;
+    }
+
+    if (gen9_pp_context_get_surface_conf(ctx, dst_surface, dst_rect,
+                                         width, height, pitch,
+                                         bo_offset)) {
+        bti = BTI_SCALING_OUTPUT_Y;
+        /* Output surface */
+
+        if (fourcc == VA_FOURCC_YUY2 || fourcc == VA_FOURCC_UYVY) {
+            gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                               bo_offset[0],
+                                               width[0] * 2, height[0],
+                                               pitch[0], 1,
+                                               I965_SURFACEFORMAT_R8_UINT,
+                                               bti, 0);
+        } else {
+            gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                               bo_offset[0],
+                                               width[0], height[0],
+                                               pitch[0], 1,
+                                               I965_SURFACEFORMAT_R8_UINT,
+                                               bti, 0);
+
+            if (fourcc == VA_FOURCC_NV12) {
+                gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                                   bo_offset[1],
+                                                   width[1] * 2, height[1],
+                                                   pitch[1], 1,
+                                                   I965_SURFACEFORMAT_R16_UINT,
+                                                   bti + 1, 0);
+            } else {
+                gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                                   bo_offset[1],
+                                                   width[1], height[1],
+                                                   pitch[1], 1,
+                                                   I965_SURFACEFORMAT_R8_UINT,
+                                                   bti + 1, 0);
+
+                gen9_add_dri_buffer_2d_gpe_surface(ctx, gpe_context, bo,
+                                                   bo_offset[2],
+                                                   width[2], height[2],
+                                                   pitch[2], 1,
+                                                   I965_SURFACEFORMAT_R8_UINT,
+                                                   bti + 2, 0);
+            }
+        }
+    }
+}
+
+VAStatus
+gen9_10bit_8bit_scaling_post_processing(VADriverContextP   ctx,
+                                        struct i965_post_processing_context *pp_context,
+                                        struct i965_surface *src_surface,
+                                        VARectangle *src_rect,
+                                        struct i965_surface *dst_surface,
+                                        VARectangle *dst_rect)
+{
+    struct i965_gpe_context *gpe_context;
+    struct gpe_media_object_walker_parameter media_object_walker_param;
+    struct intel_vpp_kernel_walker_parameter kernel_walker_param;
+
+    if (!pp_context || !src_surface || !src_rect || !dst_surface || !dst_rect)
+        return VA_STATUS_ERROR_INVALID_PARAMETER;
+
+    if (!(pp_context->scaling_gpe_context_initialized & VPPGPE_10BIT_10BIT))
+        return VA_STATUS_ERROR_UNIMPLEMENTED;
+
+    gpe_context = &pp_context->scaling_gpe_context;
+
+    gen8_gpe_context_init(ctx, gpe_context);
+    gen9_vpp_scaling_sample_state(ctx, gpe_context, src_rect, dst_rect);
+    gen9_gpe_reset_binding_table(ctx, gpe_context);
+    gen9_gpe_context_10bit_8bit_scaling_curbe(ctx, gpe_context,
+                                              src_rect, src_surface,
+                                              dst_rect, dst_surface);
+
+    gen9_gpe_context_10bit_8bit_scaling_surfaces(ctx, gpe_context,
+                                                 src_rect, src_surface,
+                                                 dst_rect, dst_surface);
+
+    gen8_gpe_setup_interface_data(ctx, gpe_context);
+
+    memset(&kernel_walker_param, 0, sizeof(kernel_walker_param));
+    kernel_walker_param.resolution_x = ALIGN(dst_rect->width, 16) >> 4;
+    kernel_walker_param.resolution_y = ALIGN(dst_rect->height, 16) >> 4;
+    kernel_walker_param.no_dependency = 1;
+
+    intel_vpp_init_media_object_walker_parameter(&kernel_walker_param, &media_object_walker_param);
+    media_object_walker_param.interface_offset = 2;
     gen9_run_kernel_media_object_walker(ctx, pp_context->batch,
                                         gpe_context,
                                         &media_object_walker_param);
