@@ -36,17 +36,16 @@
 #include "i965_structs.h"
 #include "i965_drv_video.h"
 
-#define I965_BRC_NONE	                0
-#define I965_BRC_CBR	                1
-#define I965_BRC_VBR	                2
-#define I965_BRC_CQP	                3
+#define I965_BRC_NONE                   0
+#define I965_BRC_CBR                    1
+#define I965_BRC_VBR                    2
+#define I965_BRC_CQP                    3
 
 #define WIDTH_IN_MACROBLOCKS(width)     (ALIGN(width, 16) >> 4)
 #define HEIGHT_IN_MACROBLOCKS(height)   (ALIGN(height, 16) >> 4)
-#define MAX_TEMPORAL_LAYERS	        4
+#define MAX_TEMPORAL_LAYERS         4
 
-struct intel_roi
-{
+struct intel_roi {
     short left;
     short right;
     short top;
@@ -55,15 +54,14 @@ struct intel_roi
     char  value;
 };
 
-struct intel_fraction
-{
+struct intel_fraction {
     unsigned int num;
     unsigned int den;
 };
 
-struct intel_encoder_context
-{
+struct intel_encoder_context {
     struct hw_context base;
+    VADriverContextP ctx;
     int codec;
     VASurfaceID input_yuv_surface;
     unsigned int rate_control_mode;
@@ -108,28 +106,31 @@ struct intel_encoder_context
     void *mfc_context;
     void *enc_priv_state;
 
-    unsigned int is_tmp_id:1;
-    unsigned int low_power_mode:1;
-    unsigned int soft_batch_force:1;
-    unsigned int context_roi:1;
-    unsigned int is_new_sequence:1; /* Currently only valid for H.264, TODO for other codecs */
+    unsigned int is_tmp_id: 1;
+    unsigned int low_power_mode: 1;
+    unsigned int soft_batch_force: 1;
+    unsigned int context_roi: 1;
+    unsigned int is_new_sequence: 1; /* Currently only valid for H.264, TODO for other codecs */
+
+    unsigned int fei_enabled: 1;
+    unsigned int fei_function_mode; /* configured VA_FEI_FUNCTION_XXX */
 
     void (*vme_context_destroy)(void *vme_context);
-    VAStatus (*vme_pipeline)(VADriverContextP ctx,
-                             VAProfile profile,
-                             struct encode_state *encode_state,
-                             struct intel_encoder_context *encoder_context);
+    VAStatus(*vme_pipeline)(VADriverContextP ctx,
+                            VAProfile profile,
+                            struct encode_state *encode_state,
+                            struct intel_encoder_context *encoder_context);
     void (*mfc_context_destroy)(void *mfc_context);
-    VAStatus (*mfc_pipeline)(VADriverContextP ctx,
-                             VAProfile profile,
-                             struct encode_state *encode_state,
-                             struct intel_encoder_context *encoder_context);
+    VAStatus(*mfc_pipeline)(VADriverContextP ctx,
+                            VAProfile profile,
+                            struct encode_state *encode_state,
+                            struct intel_encoder_context *encoder_context);
     void (*mfc_brc_prepare)(struct encode_state *encode_state,
                             struct intel_encoder_context *encoder_context);
 
-    VAStatus (*get_status)(VADriverContextP ctx,
-                           struct intel_encoder_context *encoder_context,
-                           struct i965_coded_buffer_segment *coded_buffer_segment);
+    VAStatus(*get_status)(VADriverContextP ctx,
+                          struct intel_encoder_context *encoder_context,
+                          struct i965_coded_buffer_segment *coded_buffer_segment);
 };
 
 extern struct hw_context *
@@ -140,6 +141,6 @@ gen8_enc_hw_context_init(VADriverContextP ctx, struct object_config *obj_config)
 
 extern struct hw_context *
 gen9_enc_hw_context_init(VADriverContextP ctx, struct object_config *obj_config);
-#endif	/* _I965_ENCODER_H_ */
+#endif  /* _I965_ENCODER_H_ */
 
 
